deezer library
Support for doing something awesome.
More dartdocs go here.
Classes
- Album
- AlbumGenre
- AlbumGenres
- AlbumTrack
- AlbumTracks
- Artist
- ArtistAlbum
- ArtistAlbums
- ArtistPlaylist
- ArtistPlaylists
- ArtistRadio
- ArtistRadios
- Artists
- ArtistTrack
- ArtistTracks
- ArtistWithPicture
- ArtistWithRole
- BaseAlbum
- BaseArtist
- BasePlaylist
- BaseTrack
- BaseUser
- Chart
- ChartAlbum
- ChartAlbums
- ChartArtist
- ChartArtists
- ChartPlaylist
- ChartPlaylists
- ChartPodcast
- ChartPodcasts
- ChartTrack
- ChartTracks
- Deezer
- FavData
- Favourites
- FlowTrack
- FlowTracks
- Genre
- Genres
- Lyrics
- LyricsSyncJson
- Playlist
- PlaylistTracks
- Radio
- RadioGenre
- RadioGenres
- Radios
- RadioTrack
- RadioTracks
- Results
- SearchAlbum
- SearchAlbums
- SngContributors
- SongData
- Track
- TrackArtists
- TrackData
- TrackResults
- Tracks
- TracksResults
- User
- UserAlbum
- UserAlbums
- UserArtist
- UserArtists
- UserChartTrack
- UserChartTracks
- UserPlaylist
- UserPlaylists
- UsersWithPic
- UserTrack
- UserTracks
- UserWithPic
Extensions
- DeezerMobile on Deezer
- The Deezer class is the main class of the package. This extension contains all the mobile API functions. It is used to convert the JSON response from the API to Dart objects.
- DeezerWeb on Deezer
- The Deezer class is the main class of the package. It is used to interact with the Deezer Web API.
Functions
-
addFavoriteSong(
Dio client, List< String> ids, String token) → Future<Response> -
decryptBlowfish(
List< int> encryptedData, Blowfish blowfish) → Future<List< int> > -
decryptMedia(
List< int> data, String sid) → Future<List< int> > -
decryptStream(
Response response, String sid, {ProgressCallback? onProgress}) → Stream< List< int> > -
generateBlowfishKey(
String id) → String -
get(
Dio client, String url) → Future< Response> -
getAccessToken(
Dio client) → Future< String> -
getAlbumPath(
ALBUM album, String id) → String -
getArtistPath(
ARTIST artist, String id) → String -
getChartPath(
CHART chart, String id) → String -
getDownloadLink(
String md5origin, String id, String format, String version) → Future< String> -
getEditorialPath(
EDITORIALS editorial, String id) → String -
getFavoriteSongs(
Dio client, String token) → Future< Response> -
getGenrePath(
GENRE genre, String id) → String -
getlink(
String? url, String typ, dynamic id) → String -
getPlaylistPath(
PLAYLIST playlist, String id) → String -
getRadioPath(
RADIO radio, String id) → String -
getSearchPath(
SEARCH search, String q) → String -
getUserPath(
USER user, String id) → String -
parseInt(
dynamic value) → int? -
parseJson<
T> (dynamic json, T fromJson(Map< String, dynamic> )) → T? -
parseList<
T> (dynamic value, T fromJson(dynamic)) → List< T> ? -
parseString(
dynamic value) → String? -
parseTotal(
dynamic value, List? dataList) → int -
removeFavoriteSong(
Dio client, List< String> ids, String token) → Future<Response> -
trackinfo(
Dio client, String id, String token) → Future< Response> -
tracksinfo(
Dio client, List< String> ids, String token) → Future<Response>
Typedefs
- ProgressCallback = void Function(int received, int total)
Exceptions / Errors
- DeezerException
- DeezerException describes the exception info.